require "_libraries/TEsound"
require "files"
require "objects"
require "buttons"
require "saving"
require "drawing"
require "music"
require "controller"

local debug = false
--Available states: menu, play, quit, gameOver

function love.load()
	gwidth = 1280
	gheight = 720
	love.window.setMode(gwidth, gheight, {vsync = true})
	width, height, flags = love.window.getMode()
	love.graphics.setColor(255, 255, 255, 255)
	love.graphics.setBackgroundColor(0, 0, 0)
	love.graphics.setDefaultFilter("nearest", "nearest")
	fileCaching()
	print("Game Launched!")
	loadGame()
	state = "menu"
	prevState = nil
	gameIsPaused = false
	buttonsDeleted = true
	PC = true
	console = false
	gravity = 1800
	groundFloor = 636
	GOtimer = 20.5 --Game Over timer
	buttons.Place()
	TEsound.volume("objects", 0.4)
	TEsound.volume("button", 0.4)
	TEsound.volume("music", 0.4)
	getGamepad()
end

function love.update(dt)
	TEsound.cleanup()
	musicPlayer()
	monitorGamepad()
	if state == "menu" then
		buttons.Place()
		buttons.Highlight()
		buttons.Sound()
	elseif state == "play" and not gameIsPaused then
		objectUpdate(dt)
		objectSpawner()
		objectRemover()
		objectCollision()
		buttons.Remove()
	elseif state == "gameOver" then
		gameOverTimer(dt)
	end
end

function love.draw()
	backgroundDraw()
	buttons.Draw()
	if state == "menu" then
		menuDraw()
		love.graphics.setColor(255, 255, 255)
		love.graphics.setFont(MainSMedium)
		love.graphics.printf("Highscore: " ..highscore, 100, gheight/2-64, gwidth, "left")
	elseif state == "play" then
		controlsDraw()
		love.graphics.setColor(255, 255, 255)
		love.graphics.circle("fill", gwidth/2, 365, 125, 100)
		love.graphics.setColor(200, 200, 200)
		love.graphics.setFont(MainHUGE)
		if player.score < 10 then
			love.graphics.printf("0" ..player.score, 0, 240, gwidth, "center")
		else
			love.graphics.printf(player.score, 0, 240, gwidth, "center")
		end
		objectDraw()
		love.graphics.setColor(255, 255, 255)
		love.graphics.setFont(MainMedium)
		love.graphics.printf("Lives: " ..player.lives, 0, 12, gwidth, "center")
		love.graphics.rectangle("line", gwidth/2-88, 12, 176, 48)
		pauseDraw()
	elseif state == "gameOver" then
		gameOverDraw()
	end
	if debug then
		debugDraw()
	end
end

function love.keypressed(key)
	if PC then
		if (state == "menu" or "play") then --[[If menu and play state--]]
			if key == "`" then
				if debug then
					debug = false
				else
					debug = true
				end
				print("Debug Menu: " ..tostring(debug))
			end
		end
		if state == "menu" then --[[If just menu state--]]
		end
		if state == "play" then --[[If just play state--]]
			if key == "f" then
				if gameIsPaused then
					gameIsPaused = false
				else
					gameIsPaused = true
				end
				print("Game Paused: " ..tostring(gameIsPaused))
			end
			if key == "escape" then
				prevState = state
				state = "menu"
				gameIsPaused = false
			end
		end
		if state == "gameOver" then
			if (key == "escape" or key == "return") then
				prevState = state
				state = "menu"
				GOtimer = 20.5
			end
		end
	end
end

function love.gamepadpressed(joystick, button)
	if console then
		if (state == "menu" or "play") then
			if button == "b" then
				if debug then
					debug = false
				else
					debug = true
				end
				print("debug menu: " ..tostring(debug))
			end
		if state == "play" then
			if button == "start" then
				if gameIsPaused then
					gameIsPaused = false
				else
					gameIsPaused = true
				end
				print("Game PuasedL " ..tostring(gameIsPaused))
			end
				if button == "back" then
					prevState = state
					state = "menu"
					gameIsPaused = false
				end
			end
			if state == "gameOver" then
				if button == "back" then
					prevState = state
					state = "menu"
					GOtimer = 20.5
				end
			end
		end
	end
end

function love.keyreleased(key)
	if state == "play" then
		if (key == "d" or "a") then
			player.xVel = 0
		end
	end
end

function love.mousepressed(x, y, button)
	if button == "l" then
		buttons.Click(x, y)
	end
end

function highscoreTracker()
	if player.score > highscore then
		highscore = player.score
	end
end

function gameOverTimer(dt)
	GOtimer = GOtimer - 1 * dt
	if GOtimer <= 0 then
		prevState = state
		state = "menu"
	end
end
