

local heartCount = 0
local boxCount = 0
local powerCount = 0

local speedUpTimerMax = 30
local speedUpTimerDefault = 0
local speedUpTimer = 0
local speedUpTimerRate = 1

local boxDefSpeed = 400
local boxDefSpeedInc = 100
local boxSpeed = boxDefSpeed

--[[Player Object]]
player = { }
function player.Place()
	player.x = 10
	player.y = 636
	player.width = 80
	player.height = 80
	player.speed = 300
	player.xVel = 0
	player.yVel = 0
	player.jumpVel = -800
	player.score = 0
	player.extraLivesScore = 0
	player.lives = 3
	player.state = "stand"
end
function player.Update(dt)
	if PC then
		useKeyboard()
	elseif console then
		useGamepad()
	end

	player.x = player.x + (player.xVel * dt)
	player.y = player.y + (player.yVel * dt)

	player.yVel = player.yVel + (gravity * dt)
end
function player.Draw()
	love.graphics.setColor(255, 255, 255)
	love.graphics.draw(playerImg, player.x, player.y, 0, 4, 4)
end
function player.Checks()
	if player.y >= groundFloor then
		player.y = groundFloor
		player.yVel = 0
		player.state = "stand"
	end
	if player.lives <= 0 then
		highscoreTracker()
		saveGame()
		state = "gameOver"
	end
	if player.extraLivesScore >= 23 then
		player.lives = player.lives + 1
		player.extraLivesScore = 0
	end
	if player.x >= (gwidth - player.width) - 4 then
		player.x = (gwidth - player.width) - 4
	elseif player.x <= 4 then
		player.x = 4
	end
end
--[[]]

--[[Box Object]]
box = {width = 100,
	height = 100,
}
function box.Spawn(x, y)
	table.insert(box, {x = x, y = y, width = box.width, height = box.height} )
end
function box.Update(dt)
	for i,v in ipairs(box) do
		v.y = v.y + boxSpeed * dt
	end
end
function box.Draw()
	for i,v in ipairs(box) do
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(boxImg, v.x, v.y, 0, 5, 5)
	end
end
--[[]]

--[[Heart Object]]
heart = {width = 80,
	height = 80,
	speed = 150,
}
function heart.Spawn(x, y)
	table.insert(heart, {x = x, y = y, width = heart.width, height = heart.height, speed = heart.speed} )
end
function heart.Update(dt)
	for i,v in ipairs(heart) do
		v.y = v.y + v.speed * dt
	end
end
function heart.Draw()
	for i,v in ipairs(heart) do
		love.graphics.setColor(255, 255, 255)
		love.graphics.draw(heartImg, v.x, v.y, 0, 4, 4)
	end
end
--[[]]

--[[General Object Functions]]
function objectUpdate(dt)
	player.Update(dt)
	player.Checks()
	heart.Update(dt)
	box.Update(dt)
	boxSpeedUp(dt)

	randomBoxX = love.math.random(0, 1180)
	randomHeartX = love.math.random(0, 1200)
	randomY = love.math.random(-500, -100)
end
function objectDraw()
	player.Draw()
	heart.Draw()
	box.Draw()
end
function objectSpawner()
	if boxCount < 3 then
		boxCount = boxCount + 1
		box.Spawn(randomBoxX, randomY)
	end
	if heartCount < 2 then
		heartCount = heartCount + 1
		heart.Spawn(randomHeartX, randomY)
	end
end
function objectRemover()
	for i,v in ipairs(box) do
		if v.y >= gheight then
			table.remove(box, i)
			boxCount = boxCount - 1
		end
	end
	for i,v in ipairs(heart) do
		if v.y >= gheight then
			table.remove(heart, i)
			heartCount = heartCount - 1
		end
	end
end
function objectRestart()
	for i,v in ipairs(box) do
		for a,b in ipairs(heart) do
			v.y = love.math.random(-500, -100)
			b.y = love.math.random(-500, -100)
		end
	end
end
function objectCollision()
	for i,v in ipairs(box) do
		if CheckCollision(player.x,player.y,player.width,player.height, v.x,v.y,v.width,v.height) then
			TEsound.play(boxHit, "objects")
			table.remove(box, i)
			boxCount = boxCount - 1
			player.lives = player.lives - 1
		end
	end
	for i,v in ipairs(heart) do
		if CheckCollision(player.x,player.y,player.width,player.height, v.x,v.y,v.width,v.height) then
			TEsound.play(heartPickup, "objects")
			table.remove(heart, i)
			heartCount = heartCount - 1
			player.score = player.score + 1
			player.extraLivesScore = player.extraLivesScore + 1
		end
	end
end
function boxSpeedUp(dt)
	speedUpTimer = speedUpTimer + speedUpTimerRate * dt
	if speedUpTimer >= speedUpTimerMax then
		boxSpeed = boxSpeed + boxDefSpeedInc
		print(boxSpeed)
		speedUpTimer = speedUpTimerDefault
	end
end
function CheckCollision(x1,y1,w1,h1, x2,y2,w2,h2)
	return x1 < x2 + w2 and
	x2 < x1 + w1 and
	y1 < y2 + h2 and
	y2 < y1 + h1
end
--[[]]
